@@ -17,16 +17,16 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Suite 500, Boston, MA 02110-1335, USA
  */
 
 #include <assert.h>
 #include <stdio.h>
 #include <windows.h>
 #include <commdlg.h>
+#include <shlwapi.h>
 
 #include "main.h"
-#include "license.h"
 #include "dialog.h"
 
 static const __WCHAR helpfileW[] = { 'n','o','t','e','p','a','d','.','h','l','p',0 };
@@ -53,67 +53,65 @@ VOID ShowLastError(void)
 
 /**
  * Sets the caption of the main window according to Globals.szFileTitle:
- *    LilyPad - (untitled)      if no file is open
- *    LilyPad - [filename]      if a file is given
+ *    Untitled - LilyPad     if no file is open
+ *    filename - LilyPad     if a file is given
  */
 static void UpdateWindowCaption(void)
 {
   __WCHAR szCaption[MAX_STRING_LEN];
-  __WCHAR szUntitled[MAX_STRING_LEN];
+  __WCHAR szLilyPad[MAX_STRING_LEN];
+  static const __WCHAR hyphenW[] = { ' ','-',' ',0 };
 
-  LoadString(Globals.hInstance, STRING_NOTEPAD, szCaption, SIZEOF(szCaption));
+  LoadString(Globals.hInstance, STRING_LILYPAD, szCaption, SIZEOF(szCaption));
 
-  if (Globals.szFileTitle[0] != '\0') {
-      static const __WCHAR bracket_lW[] = { ' ','-',' ','[',0 };
-      static const __WCHAR bracket_rW[] = { ']',0 };
-      lstrcat(szCaption, bracket_lW);
-      lstrcat(szCaption, Globals.szFileTitle);
-      lstrcat(szCaption, bracket_rW);
-  }
+  if (Globals.szFileTitle[0] != '\0')
+    lstrcpy (szCaption, Globals.szFileTitle);
   else
-  {
-      static const __WCHAR hyphenW[] = { ' ','-',' ',0 };
-      LoadString(Globals.hInstance, STRING_UNTITLED, szUntitled, SIZEOF(szUntitled));
-      lstrcat(szCaption, hyphenW);
-      lstrcat(szCaption, szUntitled);
-  }
+    LoadString(Globals.hInstance, STRING_UNTITLED, szCaption, SIZEOF(szCaption));
+
+  LoadString(Globals.hInstance, STRING_LILYPAD, szLilyPad, SIZEOF(szLilyPad));
+  lstrcat(szCaption, hyphenW);
+  lstrcat(szCaption, szLilyPad);
 
   SetWindowText(Globals.hMainWnd, szCaption);
 }
 
-static void AlertFileNotFound(__LPCWSTR szFileName)
+int DIALOG_StringMsgBox(HWND hParent, int formatId, __LPCWSTR szString, DWORD dwFlags)
 {
    __WCHAR szMessage[MAX_STRING_LEN];
    __WCHAR szResource[MAX_STRING_LEN];
 
    /* Load and format szMessage */
-   LoadString(Globals.hInstance, STRING_NOTFOUND, szResource, SIZEOF(szResource));
-   wsprintf(szMessage, szResource, szFileName);
+   LoadString(Globals.hInstance, formatId, szResource, SIZEOF(szResource));
+   wnsprintf(szMessage, SIZEOF(szMessage), szResource, szString);
 
    /* Load szCaption */
-   LoadString(Globals.hInstance, STRING_ERROR,  szResource, SIZEOF(szResource));
+   if ((dwFlags & MB_ICONMASK) == MB_ICONEXCLAMATION)
+     LoadString(Globals.hInstance, STRING_ERROR, szResource, SIZEOF(szResource));
+   else
+     LoadString(Globals.hInstance, STRING_LILYPAD, szResource, SIZEOF(szResource));
 
    /* Display Modal Dialog */
-   MessageBox(Globals.hMainWnd, szMessage, szResource, MB_ICONEXCLAMATION);
+   if (hParent == NULL)
+     hParent = Globals.hMainWnd;
+   return MessageBox(hParent, szMessage, szResource, dwFlags);
+}
+
+static void AlertFileNotFound(__LPCWSTR szFileName)
+{
+  DIALOG_StringMsgBox(0, STRING_NOTFOUND, szFileName, MB_ICONEXCLAMATION|MB_OK);
 }
 
 static int AlertFileNotSaved(__LPCWSTR szFileName)
 {
-   __WCHAR szMessage[MAX_STRING_LEN];
-   __WCHAR szResource[MAX_STRING_LEN];
    __WCHAR szUntitled[MAX_STRING_LEN];
 
    LoadString(Globals.hInstance, STRING_UNTITLED, szUntitled, SIZEOF(szUntitled));
 
-   /* Load and format Message */
-   LoadString(Globals.hInstance, STRING_NOTSAVED, szResource, SIZEOF(szResource));
-   wsprintf(szMessage, szResource, szFileName[0] ? szFileName : szUntitled);
-
-   /* Load Caption */
-   LoadString(Globals.hInstance, STRING_ERROR, szResource, SIZEOF(szResource));
-
-   /* Display modal */
-   return MessageBox(Globals.hMainWnd, szMessage, szResource, MB_ICONEXCLAMATION|MB_YESNOCANCEL);
+   return DIALOG_StringMsgBox(0,
+			      STRING_NOTSAVED,
+			      szFileName[0] ? szFileName : szUntitled,
+			      MB_ICONQUESTION|MB_YESNOCANCEL);
 }
 
 /**
@@ -189,10 +187,8 @@ BOOL DoCloseFile(void)
             case IDNO:      break;
 
             case IDCANCEL:  return(FALSE);
-                            break;
 
             default:        return(FALSE);
-                            break;
         } /* switch */
     } /* if */
 
@@ -207,7 +203,7 @@ void DoOpenFile(__LPCWSTR szFileName)
 {
     static const __WCHAR dotlog[] = { '.','L','O','G',0 };
     HANDLE hFile;
-    LPSTR pTemp;
+    __LPWSTR pTemp;
     DWORD size;
     DWORD dwNumRead;
     __WCHAR log[5];
@@ -220,7 +216,7 @@ void DoOpenFile(__LPCWSTR szFileName)
 	OPEN_EXISTING, FILE_ATTRIBUTE_NORMAL, NULL);
     if(hFile == INVALID_HANDLE_VALUE)
     {
-	ShowLastError();
+        AlertFileNotFound(szFileName);
 	return;
     }
 
@@ -258,11 +254,11 @@ void DoOpenFile(__LPCWSTR szFileName)
 	__LPWSTR p = (__LPWSTR)pTemp;
 	/* We need to strip BOM Unicode character, SetWindowTextW won't do it for us. */
 	if (*p == 0xFEFF || *p == 0xFFFE) p++;
-	SetWindowTextW(Globals.hEdit, p);
+	SetWindowText(Globals.hEdit, p);
     }
     else
 #endif
-	SetWindowTextA(Globals.hEdit, pTemp);
+	SetWindowText(Globals.hEdit, pTemp);
 
     HeapFree(GetProcessHeap(), 0, pTemp);
 
@@ -273,12 +269,7 @@ void DoOpenFile(__LPCWSTR szFileName)
     /*  If the file starts with .LOG, add a time/date at the end and set cursor after
      *  See http://support.microsoft.com/?kbid=260563
      */
-    if (
-#ifdef UNICODE
-	GetWindowTextW
-#else
-	GetWindowTextA
-#endif
+    if (GetWindowText
 	(Globals.hEdit, log, sizeof(log)/sizeof(log[0])) && !lstrcmp(log, dotlog))
     {
 	static const __WCHAR lfW[] = { '\r','\n',0 };
@@ -329,12 +320,8 @@ VOID DIALOG_FileOpen(VOID)
     openfilename.lpstrDefExt       = szDefaultExt;
 
 
-    if (GetOpenFileName(&openfilename)) {
-        if (FileExists(openfilename.lpstrFile))
-            DoOpenFile(openfilename.lpstrFile);
-        else
-            AlertFileNotFound(openfilename.lpstrFile);
-    }
+    if (GetOpenFileName(&openfilename))
+	DoOpenFile(openfilename.lpstrFile);
 }
 
 
@@ -413,6 +400,8 @@ VOID DIALOG_FilePrint(VOID)
     ZeroMemory(&printer, sizeof(printer));
     printer.lStructSize           = sizeof(printer);
     printer.hwndOwner             = Globals.hMainWnd;
+    printer.hDevMode              = Globals.hDevMode;
+    printer.hDevNames             = Globals.hDevNames;
     printer.hInstance             = Globals.hInstance;
     
     /* Set some default flags */
@@ -428,6 +417,9 @@ VOID DIALOG_FilePrint(VOID)
 
     if (!PrintDlg(&printer)) return;
 
+    Globals.hDevMode = printer.hDevMode;
+    Globals.hDevNames = printer.hDevNames;
+
     assert(printer.hDC != 0);
 
     /* initialize DOCINFO */
@@ -525,11 +517,16 @@ VOID DIALOG_FilePrinterSetup(VOID)
     ZeroMemory(&printer, sizeof(printer));
     printer.lStructSize         = sizeof(printer);
     printer.hwndOwner           = Globals.hMainWnd;
+    printer.hDevMode            = Globals.hDevMode;
+    printer.hDevNames           = Globals.hDevNames;
     printer.hInstance           = Globals.hInstance;
     printer.Flags               = PD_PRINTSETUP;
     printer.nCopies             = 1;
 
     PrintDlg(&printer);
+
+    Globals.hDevMode = printer.hDevMode;
+    Globals.hDevNames = printer.hDevNames;
 }
 
 VOID DIALOG_FileExit(VOID)
@@ -586,6 +583,7 @@ VOID DIALOG_EditTimeDate(VOID)
 
 VOID DIALOG_EditWrap(VOID)
 {
+    BOOL modify = FALSE;
     static const __WCHAR editW[] = { 'e','d','i','t',0 };
     DWORD dwStyle = WS_CHILD | WS_VISIBLE | WS_BORDER | WS_VSCROLL |
                     ES_AUTOVSCROLL | ES_MULTILINE;
@@ -601,6 +599,7 @@ VOID DIALOG_EditWrap(VOID)
         return;
     }
     GetWindowText(Globals.hEdit, pTemp, size);
+    modify = SendMessage(Globals.hEdit, EM_GETMODIFY, 0, 0);
     DestroyWindow(Globals.hEdit);
     GetClientRect(Globals.hMainWnd, &rc);
     if( Globals.bWrapLongLines ) dwStyle |= WS_HSCROLL | ES_AUTOHSCROLL;
@@ -608,11 +607,8 @@ VOID DIALOG_EditWrap(VOID)
                          0, 0, rc.right, rc.bottom, Globals.hMainWnd,
                          NULL, Globals.hInstance, NULL);
     SendMessage(Globals.hEdit, WM_SETFONT, (WPARAM)Globals.hFont, (LPARAM)FALSE);
-#ifdef UNICODE
-    SetWindowTextW(Globals.hEdit, pTemp);
-#else
-    SetWindowTextA(Globals.hEdit, pTemp);
-#endif
+    SetWindowText(Globals.hEdit, pTemp);
+    SendMessage(Globals.hEdit, EM_SETMODIFY, (WPARAM)modify, 0);
     SetFocus(Globals.hEdit);
     HeapFree(GetProcessHeap(), 0, pTemp);
     
@@ -630,7 +626,7 @@ VOID DIALOG_SelectFont(VOID)
     cf.lStructSize=sizeof(cf);
     cf.hwndOwner=Globals.hMainWnd;
     cf.lpLogFont=&lf;
-    cf.Flags=CF_SCREENFONTS;
+    cf.Flags=CF_SCREENFONTS | CF_INITTOLOGFONTSTRUCT;
 
     if( ChooseFont(&cf) )
     {
@@ -652,7 +648,7 @@ VOID DIALOG_Search(VOID)
         Globals.find.hInstance        = Globals.hInstance;
         Globals.find.lpstrFindWhat    = Globals.szFindText;
         Globals.find.wFindWhatLen     = SIZEOF(Globals.szFindText);
-        Globals.find.Flags            = FR_DOWN;
+        Globals.find.Flags            = FR_DOWN|FR_HIDEWHOLEWORD;
 
         /* We only need to create the modal FindReplace dialog which will */
         /* notify us of incoming events using hMainWnd Window Messages    */
@@ -663,8 +659,10 @@ VOID DIALOG_Search(VOID)
 
 VOID DIALOG_SearchNext(VOID)
 {
-    /* FIXME: Search Next */
-    DIALOG_Search();
+    if (Globals.lastFind.lpstrFindWhat == NULL)
+        DIALOG_Search();
+    else                /* use the last find data */
+        LILYPAD_DoFind(&Globals.lastFind);
 }
 
 VOID DIALOG_HelpContents(VOID)
@@ -682,23 +680,14 @@ VOID DIALOG_HelpHelp(VOID)
     WinHelp(Globals.hMainWnd, helpfileW, HELP_HELPONHELP, 0);
 }
 
-VOID DIALOG_HelpLicense(VOID)
-{
-        WineLicense(Globals.hMainWnd);
-}
-
-VOID DIALOG_HelpNoWarranty(VOID)
-{
-        WineWarranty(Globals.hMainWnd);
-}
-
-VOID DIALOG_HelpAboutWine(VOID)
+VOID DIALOG_HelpAboutLilyPad(VOID)
 {
     static const __WCHAR lilypadW[] = { 'L','i','l','y','P','a','d','\n',0 };
     __WCHAR szLilyPad[MAX_STRING_LEN];
+    HICON icon = LoadIcon(Globals.hInstance, MAKEINTRESOURCE(IDI_LILYPAD));
 
-    LoadString(Globals.hInstance, STRING_NOTEPAD, szLilyPad, SIZEOF(szLilyPad));
-    ShellAbout(Globals.hMainWnd, szLilyPad, lilypadW, 0);
+    LoadString(Globals.hInstance, STRING_LILYPAD, szLilyPad, SIZEOF(szLilyPad));
+    ShellAbout(Globals.hMainWnd, szLilyPad, lilypadW, icon);
 }
 
 
